#!/bin/sh
#
# Author: Make chroot environment to test Skolelinux package install.
# Date:   2002-01-05
#
# Test installation of Skolelinux packages.
#
# Options:
#    manual  - stop after debootstrap is done.
#    notasks - stop before tasks would be installed.
#    keep    - do not delete the changeroot environment when done.

set -e

basemirror=http://ftp.skolelinux.no
targetdir=/home/pere/tmp/chroot
#cdimage=/skolelinux/developer/local0/ftp/debian-cd/woody-i386-1.raw

date
echo

if test ! -z "$cdimage" ; then
	# Make sure we unmount the previous try
	umount $targetdir/cdrom > /dev/null 2>&1 || true

	mkdir -p $targetdir/cdrom
	if ! mount $cdimage $targetdir/cdrom -o loop=/dev/loop1
	then
		echo "Unable to mount CD before running debootstrap.  Exiting."
		exit
	fi
	basemirror=file:$targetdir/cdrom
fi

INCLUDE=--include=locales

if ! /usr/sbin/debootstrap $INCLUDE --arch i386 woody \
  $targetdir $basemirror/debian < /dev/null
then
	echo "Failed to bootstrap chroot environment.  Exiting."
	exit
fi

echo
echo /etc
echo
ls -l $targetdir/etc

# Fake reboot, do the things that would be done on reboot
chroot $targetdir mount /proc
echo skolelinux > $targetdir/etc/mailname

# Prepare APT source
if test -z "$cdimage"; then
	cat > $targetdir/etc/apt/sources.list <<EOF
deb $basemirror/debian woody main non-free contrib
deb $basemirror/debian-non-US woody/non-US main contrib non-free
deb ftp://ftp.skolelinux.no/skolelinux woody local
EOF
else
	cat > $targetdir/etc/apt/sources.list <<EOF
deb file:/cdrom woody main non-free contrib local non-US/main non-US/contrib non-US/non-free
#deb $basemirror/debian woody main non-free contrib
#deb $basemirror/debian-non-US woody/non-US main contrib non-free
#deb ftp://ftp.skolelinux.no/skolelinux woody local
EOF
fi

if test xmanual = x$1; then
	exit 0
fi

chroot $targetdir apt-get update

# Make sure we do not start any daemons in the chroot environment
mv $targetdir/sbin/start-stop-daemon $targetdir/sbin/start-stop-daemon.debian
cat > $targetdir/sbin/start-stop-daemon <<EOF
#!/bin/sh
echo 1>&2
echo 'Warning: Fake start-stop-daemon called, doing nothing.' 1>&2
exit 0
EOF
chmod a+rx $targetdir/sbin/start-stop-daemon

if test xnotasks = x$1; then
	exit 0
fi

mkdir -p $targetdir/etc/skolelinux
(
  echo "PROFILE=\"Workstation, LTSP-server, Server\""
#  echo "PROFILE=\"Server\""
  echo "LANGUAGE=nb"
) > $targetdir/etc/skolelinux/config

# Make sure that cfengine understand that this is install time.
touch $targetdir/root/dbootstrap_settings

# Install our overrides
chroot $targetdir apt-get install -y base-config-skolelinux < /dev/null

# Run base-config to install everything
echo "Running base-config"

# Use BASE_CONFIG_IN_SCRIPT=1 to avoid starting script in base-config.  When
# it did, it forked the process into the backgrond, and this then started
# to remove the $target directory...

if DEBIAN_FRONTEND=noninteractive BASE_CONFIG_IN_SCRIPT=1 \
    chroot $targetdir base-config < /dev/null
then
	echo "Successfull base-config"
else
	echo "Failed to run base-config"
fi

echo "Disk usage:"
du -sh $targetdir || true

echo "Dump current debconf database."
chroot $targetdir /usr/sbin/filter-config-dat /var/cache/debconf/config.dat > \
  config-data-current.txt || true

if test xkeep = x$1; then
	echo
	echo "Keeping $targetdir"
	echo
else
	echo
	echo "Removing $targetdir"
	echo
	# Remove the test directory
	if test ! -z "$cdimage"; then
		umount $targetdir/cdrom
	fi
	chroot $targetdir umount /proc
	test -d $targetdir && rm -rf $targetdir
fi

echo
echo "Done testing"
echo
date
